Contributing to Connexion/TODOs
===============================

We welcome your ideas, issues, and pull requests. Just follow the usual/standard GitHub practices.

Unless you explicitly state otherwise in advance, any non trivial 
contribution intentionally submitted for inclusion in this project by you 
to the steward of this repository (Zalando SE, Berlin) shall be under the 
terms and conditions of the `Apache License 2.0`_, 
without any additional copyright information, terms or conditions.


TODOs
-----

If you'd like to become a more consistent contributor to Connexion, we'd love your help working on 
these we have a list of `issues where we are looking for contributions`_.

.. _issues where we are looking for contributions: https://github.com/zalando/connexion/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22
.. _Apache License 2.0: README.rst#license
